@@ -423,7 +423,7 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
 
 
 def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
-        result_fields=(), translations={}):
+        result_fields=(), translations={}, extra_filters={}):
     is_overall_search = request.GET.get('is_overall_search', '')
     (fields, class_name, class_name_lower, ajax_url, charfield_exists, \
             datetimefield_exists, booleanfield_exists) = \
@@ -498,6 +498,8 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
             print('dt = %s' % dt)
         else:
             ret_dic['objects'] = Obj.objects.all()
+    if extra_filters:
+        ret_dic['objects'] = ret_dic['objects'].filter(**extra_filters)
     print(request.GET)
     ret_dic['all_id'] = ','.join([str(obj.id) for obj in \
             ret_dic['objects']])
